%% Demo: time delayed mutual information

%% Setting
std = 2; % standard deviation

% Generate random sequences bounded to [1 10]
x = round(rand(500,1)*9)+1;
y = x + round(std*randn(500,1)); % generate y from x with added noise 
y(y>10) = 10;
y(y<1) = 1;
z = round(rand(500,1)*9)+1;

data(1,:) = x(1:300);   % sequence x
data(2,:) = y(101:400); % sequence y advances sequence x at 100 frames
data(3,:) = z(1:300);   % a totally irrelavant sequence z

%% Main Routine
lag = -150:150;
method = 'tdmi';
binVec = [10 10 10];
verbose = 1;

[relMat delayMat f] = vsFindDelayRelation(data, lag, method, ...
    binVec, verbose);

% Plot the TDMI function of sequence x and y
plot(lag, f{1,2}); % there is a clear peak at time delay = 100
xlim([lag(1) lag(end)]);
ylabel('Time Delayed Mutual Information');
xlabel('Time Index');

